@@ -5,7 +5,8 @@ from .utils import validator
 @validator
 def between(value, min=None, max=None):
     """
-    Validates that a number is between minimum and/or maximum value.
+    Validate that a number is between minimum and/or maximum value.
+
     This will work with any comparable type, such as floats, decimals and dates
     not just integers.
 
@@ -16,21 +17,22 @@ def between(value, min=None, max=None):
 
     Examples::
 
-        >>> import validators
-
-        >>> assert validators.between(5, min=2)
-
-        >>> assert validators.between(13.2, min=13, max=14)
-
-        >>> assert not validators.between(500, max=400)
-
         >>> from datetime import datetime
 
-        >>> assert validator.between(
+        >>> between(5, min=2)
+        True
+
+        >>> between(13.2, min=13, max=14)
+        True
+
+        >>> between(500, max=400)
+        ValidationFailure(func=between, args=...)
+
+        >>> between(
         ...     datetime(2000, 11, 11),
         ...     min=datetime(1999, 11, 11)
         ... )
-
+        True
 
     :param min:
         The minimum required value of the number. If not provided, minimum
@@ -49,7 +51,11 @@ def between(value, min=None, max=None):
         min = Min
     if max is None:
         max = Max
-    if min > max:
+    try:
+        min_gt_max = min > max
+    except TypeError:
+        min_gt_max = max < min
+    if min_gt_max:
         raise AssertionError('`min` cannot be more than `max`.')
 
-    return min <= value <= max
+    return min <= value and max >= value
