@@ -8,8 +8,10 @@ pattern = re.compile(r'^(?:[0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}$')
 @validator
 def mac_address(value):
     """
-    Returns whether or not given value is a valid mac address. If the value is
-    valid mac address this function returns True, otherwise `FailedValidation`.
+    Return whether or not given value is a valid MAC address.
+
+    If the value is valid MAC address this function returns ``True``,
+    otherwise :class:`~validators.utils.ValidationFailure`.
 
     This validator is based on `WTForms MacAddress validator`_.
 
@@ -18,9 +20,11 @@ def mac_address(value):
 
     Examples::
 
-        >>> assert validators.mac_address('01:23:45:67:ab:CD')
+        >>> mac_address('01:23:45:67:ab:CD')
+        True
 
-        >>> assert not validators.mac_address('00:00:00:00:00')
+        >>> mac_address('00:00:00:00:00')
+        ValidationFailure(func=mac_address, args={'value': '00:00:00:00:00'})
 
     .. versionadded:: 0.2
 
