@@ -8,8 +8,10 @@ pattern = re.compile(r'^[0-9a-fA-F]{8}-([0-9a-fA-F]{4}-){3}[0-9a-fA-F]{12}$')
 @validator
 def uuid(value):
     """
-    Returns whether or not given value is a valid uuid. If the value is valid
-    uuid this function returns True, otherwise `FailedValidation`.
+    Return whether or not given value is a valid UUID.
+
+    If the value is valid UUID this function returns ``True``, otherwise
+    :class:`~validators.utils.ValidationFailure`.
 
     This validator is based on `WTForms UUID validator`_.
 
@@ -18,12 +20,11 @@ def uuid(value):
 
     Examples::
 
-        >>> import validators
-
-        >>> assert validators.uuid('2bc1c94f-0deb-43e9-92a1-4775189ec9f8')
-
-        >>> assert not validators.uuid('2bc1c94f 0deb-43e9-92a1-4775189ec9f8')
+        >>> uuid('2bc1c94f-0deb-43e9-92a1-4775189ec9f8')
+        True
 
+        >>> uuid('2bc1c94f 0deb-43e9-92a1-4775189ec9f8')
+        ValidationFailure(func=uuid, ...)
 
     .. versionadded:: 0.2
 
